Struct libcec_sys::cec_command
source · [−]#[repr(C)]pub struct cec_command {
pub initiator: cec_logical_address,
pub destination: cec_logical_address,
pub ack: i8,
pub eom: i8,
pub opcode: cec_opcode,
pub parameters: cec_datapacket,
pub opcode_set: i8,
pub transmit_timeout: i32,
}Fields
initiator: cec_logical_address< the logical address of the initiator of this message
destination: cec_logical_address< the logical address of the destination of this message
ack: i8< 1 when the ACK bit is set, 0 otherwise
eom: i8< 1 when the EOM bit is set, 0 otherwise
opcode: cec_opcode< the opcode of this message
parameters: cec_datapacket< the parameters attached to this message
opcode_set: i8< 1 when an opcode is set, 0 otherwise (POLL message)
transmit_timeout: i32< the timeout to use in ms